package com.namomedia.android;

import android.content.Context;
import android.net.ConnectivityManager;
import android.net.NetworkInfo;

/**
 * Helper class to check the devices current connection.
 */
class Connectivity {

  /**
   * Get the network info
   */
  private static NetworkInfo getNetworkInfo(Context context) {
    if (!Permissions.hasAccessNetworkStatePermission(context)) {
      return null;
    }
    ConnectivityManager manager =
        (ConnectivityManager) context.getSystemService(Context.CONNECTIVITY_SERVICE);
    return manager.getActiveNetworkInfo();
  }

  /**
   * Connection Type values and their query params.
   */
  enum NetworkStatus {
    /** Connected via Wifi */
    CONNECTED_WIFI,
    /** Connection via a mobile data connection */
    CONNECTED_MOBILE,
    /** Connected, but not sure how */
    CONNECTED_OTHER,
    /** Not connected to the network */
    DISCONNECTED,
    /** Unknown whether we're connected to the network, the app likely doesn't have permissions */
    UNKNOWN;

    String toUrlString() {
      // These strings are a subset of what is supported on both iOS and Android.
      if (this == CONNECTED_WIFI) {
        return "wifi";
      } else if (this == CONNECTED_MOBILE) {
        return "mobile";
      }
      return "unknown";
    }
  }

  /**
   * Get the current connection type.
   */
  static NetworkStatus getConnectionType(Context context) {
    NetworkInfo info = Connectivity.getNetworkInfo(context);
    if (info == null) {
      return NetworkStatus.UNKNOWN;
    }
    if (!info.isConnected()) {
      return NetworkStatus.DISCONNECTED;
    }
    switch (info.getType()) {
      case ConnectivityManager.TYPE_WIFI:
      case ConnectivityManager.TYPE_WIMAX:
        return NetworkStatus.CONNECTED_WIFI;
      case ConnectivityManager.TYPE_MOBILE:
      case ConnectivityManager.TYPE_MOBILE_DUN:
      case ConnectivityManager.TYPE_MOBILE_HIPRI:
      case ConnectivityManager.TYPE_MOBILE_MMS:
      case ConnectivityManager.TYPE_MOBILE_SUPL:
        return NetworkStatus.CONNECTED_MOBILE;
      default:
        return NetworkStatus.CONNECTED_OTHER;
    }
  }
}
