package com.namomedia.android;

/**
 * Enumeration utilities.
 */
class Enums {
  /**
   * Returns an optional enum constant for the given type, ignoring case. If the
   * constant does not exist, null is returned. This function assumes that the enum values follow
   * proper Java coding conventions by consisting of upper-case characters.
   */
  public static <T extends Enum<T>> T valueIfPresent(Class<T> enumClass, String value) {
    if (value == null) {
      return null;
    }

    try {
      return Enum.valueOf(enumClass, value.toUpperCase());
    } catch (IllegalArgumentException ignored) {
      return null;
    }
  }
}
