package com.namomedia.android;

import android.widget.ImageView;

/**
 * Implementation for NamoImageLoader interface.
 */
class ImageLoaderImpl implements NamoImageLoader {
  private final BackendClient backendClient;
  private final String imageUrl;
  private final String imageMetadata;
  private int placeholderResId = R.drawable.namo_placeholder;
  private int errorResId = R.drawable.namo_error_placeholder;

  private ViewSizeWaiter<ImageView> viewSizeWaiter;

  ImageLoaderImpl(BackendClient backendClient, String imageUrl) {
    this(backendClient, imageUrl, null);
  }

  ImageLoaderImpl(BackendClient backendClient, String imageUrl, String imageMetadata) {
    this.backendClient = backendClient;
    Preconditions.checkNotNull(imageUrl);
    this.imageUrl = imageUrl;
    this.imageMetadata = imageMetadata;
  }

  @Override
  public NamoImageLoader placeholder(int placeholderResId) {
    this.placeholderResId = placeholderResId;
    return this;
  }

  @Override
  public NamoImageLoader errorPlaceholder(int errorResId) {
    this.errorResId = errorResId;
    return this;
  }

  @Override
  public void into(ImageView imageView) {
    viewSizeWaiter = new ViewSizeWaiter<ImageView>(imageView);
    viewSizeWaiter.setListener(new ViewSizeWaiter.SizeListener<ImageView>() {
      @Override
      public void onHasSize(ImageView imageView) {
        String url = generateImageUrl(imageView);
        backendClient.fetchSizedImage(url, imageView, placeholderResId, errorResId);
      }

      @Override
      public void onFinished() {
        viewSizeWaiter = null;
      }
    });
  }

  private String generateImageUrl(ImageView imageView) {
    // Is this imageUrl one that we can resize?
    if (!backendClient.isImageServerUrl(imageUrl)) {
      return imageUrl;
    }

    // Pull off the file extension.
    StringBuilder outputUrl = new StringBuilder();
    int extensionIdx = imageUrl.lastIndexOf(".");
    outputUrl.append(imageUrl.substring(0, extensionIdx));

    // Compute the target image size.
    int targetWidth = imageView.getWidth();
    int targetHeight = imageView.getHeight();
    outputUrl.append(String.format("_%d_%d", targetWidth, targetHeight));

    // Recombine the entire Url.
    if (imageMetadata != null) {
      outputUrl.append("_");
      outputUrl.append(imageMetadata);
    }
    outputUrl.append(imageUrl.substring(extensionIdx, imageUrl.length()));
    return outputUrl.toString();
  }
}
