package com.namomedia.android;


import android.net.Uri;
import com.namomedia.android.volley.AuthFailureError;
import com.namomedia.android.volley.NetworkResponse;
import com.namomedia.android.volley.ParseError;
import com.namomedia.android.volley.Request;
import com.namomedia.android.volley.Response;
import com.namomedia.android.volley.toolbox.HttpHeaderParser;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.io.UnsupportedEncodingException;
import java.util.Collection;
import java.util.HashMap;
import java.util.Locale;
import java.util.Map;
import java.util.Set;

/**
 * A request for retrieving ads or logging interactions such as clicks and impressions.
 */
class JsonRequest extends Request<JSONObject> {

  private final Response.Listener<JSONObject> listener;

  /**
   * Creates a new request using the given URL. Calls a listener or errorListener when finished.
   */
  JsonRequest(String url,
      Response.Listener<JSONObject> listener, Response.ErrorListener errorListener) {
    super(Method.GET, url, errorListener);
    this.listener = listener;
    this.setShouldCache(false);
  }

  JsonRequest(String baseUrl, RequestParams params,
      Response.Listener<JSONObject> listener, Response.ErrorListener errorListener) {
    this(buildUrl(baseUrl, params), listener, errorListener);
  }

  private static String buildUrl(String baseUrl, RequestParams requestParams) {
    Uri.Builder builder = Uri.parse(baseUrl).buildUpon();
    Preconditions.checkNotNull(builder);
    requestParams.addToBuilder(builder);
    return builder.build().toString();
  }

  @Override
  public Map<String, String> getHeaders() throws AuthFailureError {
    Map<String, String> headers = new HashMap<String, String>();
    Locale locale = Locale.getDefault();
    headers.put("Accept-Language", locale.getLanguage() + "-" + locale.getCountry());
    return headers;
  }

  @Override
  protected Response<JSONObject> parseNetworkResponse(NetworkResponse response) {
    try {
      String json = new String(response.data, HttpHeaderParser.parseCharset(response.headers));
      JSONObject jsonObject = new JSONObject(json);
      return Response.success(jsonObject, /* no cache entry */ null);
    } catch (UnsupportedEncodingException e) {
      return Response.error(new ParseError(e));
    } catch (JSONException je) {
      return Response.error(new ParseError(je));
    }

  }

  @Override
  protected void deliverResponse(JSONObject response) {
    listener.onResponse(response);
  }
}