/**
 * Note: Portions of this file are a derivative work from Android's volley library, which
 * is covered by the Apache License, Version 2.0, which can be obtained here:
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * See the original source here:
 * https://android.googlesource.com/platform/frameworks/volley/+/master/src/com/android/volley
 */

package com.namomedia.android;

import android.util.Log;

import java.util.Locale;

/**
 * Logging helper class.
 */
class LogHelper {
  static String TAG = "Namo";

  static final boolean DEBUG = Log.isLoggable(TAG, Log.VERBOSE);

  static void v(String format, Object... args) {
    if (DEBUG) {
      Log.v(TAG, buildMessage(format, args));
    }
  }

  static void d(String format, Object... args) {
    Log.d(TAG, buildMessage(format, args));
  }

  static void i(String format, Object... args) {
    Log.i(TAG, buildMessage(format, args));
  }

  static void w(String format, Object... args) {
    Log.w(TAG, buildMessage(format, args));
  }

  static void e(String format, Object... args) {
    Log.e(TAG, buildMessage(format, args));
  }

  static void wtf(String format, Object... args) {
    Log.wtf(TAG, buildMessage(format, args));
  }

  static void wtf(Throwable tr, String format, Object... args) {
    Log.wtf(TAG, buildMessage(format, args), tr);
  }

  /**
   * Formats the caller's provided message and prepends useful info like
   * calling thread ID and method name.
   */
  private static String buildMessage(String format, Object... args) {
    String msg = (args == null) ? format : String.format(Locale.US, format, args);
    StackTraceElement[] trace = new Throwable().fillInStackTrace().getStackTrace();

    String caller = "<unknown>";
    // Walk up the stack looking for the first caller outside of LogHelper, starting 2 frames up.
    for (int i = 2; i < trace.length; i++) {
      Class<?> clazz = trace[i].getClass();
      if (!clazz.equals(LogHelper.class)) {
        String callingClass = trace[i].getClassName();
        callingClass = callingClass.substring(callingClass.lastIndexOf('.') + 1);
        callingClass = callingClass.substring(callingClass.lastIndexOf('$') + 1);

        caller = callingClass + "." + trace[i].getMethodName();
        break;
      }
    }
    return String.format(Locale.US, "[%d] %s: %s",
        Thread.currentThread().getId(), caller, msg);
  }
}