package com.namomedia.android;

import android.app.Activity;
import android.content.Context;
import android.content.res.Configuration;
import android.media.MediaPlayer;
import android.os.Bundle;
import android.view.ViewGroup;
import android.view.Window;
import android.widget.MediaController;
import android.widget.RelativeLayout;
import android.widget.VideoView;

/**
 * The activity used by the Namo Media SDK to display advertising content. In order to use the Namo
 * Media SDK, you will need to add the following tag to your AndroidManifest.xml, inside your
 * application tag:
 *
 * <code>
 *   <activity
 *     android:name="com.namomedia.android.NamoAdActivity"
 *     android:configChanges="keyboard|keyboardHidden|orientation|screenLayout|uiMode|screenSize|smallestScreenSize" />
 * </code>
 *
 * @since Namo 1.0
 */
public class NamoAdActivity extends Activity {

  public static final String VIDEO_URL = "videoUrl";

  private String videoUrl;
  private MediaController mediaController;
  private RelativeLayout parentView;
  private VideoView videoView;
  private int currentPosition = 0;

  @Override
  protected void onCreate(Bundle savedInstanceState) {
    super.onCreate(savedInstanceState);
    videoUrl = getIntent().getStringExtra(VIDEO_URL);
    if (videoUrl == null || videoUrl.equals("")) {  // isEmpty is not available until API 9.
      videoUrl = null;
      finish();
      return;
    }

    // TODO(joe): Add controls like "back"? Add an action on video?
    requestWindowFeature(Window.FEATURE_NO_TITLE);
    parentView = new RelativeLayout(this);
    parentView.setBackgroundColor(getResources().getColor(android.R.color.black));
    RelativeLayout.LayoutParams parentParams = new RelativeLayout.LayoutParams(
        RelativeLayout.LayoutParams.FILL_PARENT, RelativeLayout.LayoutParams.FILL_PARENT);
    videoView = new VideoView(this);
    RelativeLayout.LayoutParams tvParams = new RelativeLayout.LayoutParams(
        RelativeLayout.LayoutParams.FILL_PARENT, RelativeLayout.LayoutParams.FILL_PARENT);
    tvParams.addRule(RelativeLayout.CENTER_IN_PARENT);
    mediaController = new MediaController(this);
    videoView.setLayoutParams(tvParams);
    videoView.setMediaController(mediaController);
    videoView.setOnCompletionListener(new MediaPlayer.OnCompletionListener() {
      @Override
      public void onCompletion(MediaPlayer mediaPlayer) {
        // TODO(joe): Log completed impression.
        finish();
      }
    });
    parentView.addView(videoView);
    setContentView(parentView, parentParams);
  }

  @Override
  public void onConfigurationChanged(Configuration newConfig) {
    // TODO(joe): Deal with screen orientation changes.
    super.onConfigurationChanged(newConfig);
  }

  @Override
  protected void onResume() {
    super.onResume();
    // Set up the  video URL & mediaPlayer if needed.
    videoView.setVideoPath(videoUrl);
    videoView.seekTo(currentPosition);
    // TODO(joe): Figure out how to get resume to work.
    // TODO(joe): Log video start if currentPosition is zero.
    videoView.start();
  }

  @Override
  protected void onPause() {
    super.onPause();
    videoView.pause();
    currentPosition = videoView.getCurrentPosition();
  }

  @Override
  protected void onStop() {
    // TODO(joe): Test this. Our activity data may get destroyed here - might need bundle state.
    super.onStop();
    videoView.pause();
    currentPosition = videoView.getCurrentPosition();
  }
}
