package com.namomedia.android;

/**
 * The data for a Namo ad returned from the server.
 * <p>
 * This class comes into play when programmatically binding your list items to an ad. See our
 * <a href="http://docs.namomedia.com/android/">Getting Started Guide</a> for examples.
 *
 * @since 1.0
 */
public interface NamoAdData {

  /**
   * The action type associated with this ad.
   * <p>
   * You may want to show a different UI for different action types. For example, you could show
   * an "INSTALL " button for an install ad, or a "Play Image" overlay for a video ad. The SDK will
   * correctly handle different action types when clicking on your ad view.
   *
   * @return The action type associated with this ad.
   * @since 1.0
   */
  NamoActionType getActionType();

  /**
   * Starts an image request for the primary ad image.
   * <p>
   * To load the image into an ImageView, call
   * <code>loadImage().into(imageView)</code>. This will start an image request for an
   * image with the correct dimensions for the ImageView, and asynchronously load it into the
   * target view. If recently loaded, the image may be retrieved from memory cache.
   *
   * {@see com.namomedia.android.R.id#namo_ad_image}
   * @return A {@link NamoImageLoader} object.
   * @since 1.0
   */
  NamoImageLoader loadImage();

  /**
   * Gets an image loader for the advertiser icon.
   * <p>
   * To load the icon into an ImageView, call
   * <code>loadAdvertiserIcon().into(imageView)</code>. This will start an image request for the
   * icon with the correct dimensions for the ImageView, and asynchronously load it into the
   * target view. If recently loaded, the image may be retrieved from memory cache.
   *
   * {@see com.namomedia.android.R.id#namo_advertiser_icon}
   * @return A {@link NamoImageLoader} object.
   * @since 1.0
   */
  NamoImageLoader loadAdvertiserIcon();

  /**
   * Gets a text loader for the ad text.
   * <p>
   * To set the text into a TextView, call
   * <code>loadText().into(textView)</code>. This will measure the TextView on the next drawing
   * pass and load the ad text of the appropriate length into the target view.
   *
   * {@see com.namomedia.android.R.id#namo_ad_text}
   * @return A {@link NamoImageLoader} object.
   * @since 2.0
   */
  NamoTextLoader loadText();

  /**
   * Gets a text loader for the advertiser name.
   * <p>
   * To set the text into a TextView, call
   * <code>loadText().into(textView)</code>. This will measure the TextView on the next drawing
   * pass and load the ad text of the appropriate length into the target view.
   *
   * {@see R.id#namo_advertiser_name}
   * @return The advertiser name for this ad.
   * @since 2.0
   */
  NamoTextLoader loadAdvertiserName();
}
