package com.namomedia.android;

import android.widget.ImageView;

/**
 * Fluent API for requesting an image from the Namo servers and loading it into a target
 * {@code ImageView}.
 *
 * @since 1.0
 */
public interface NamoImageLoader {
  /**
   * A placeholder drawable to be used while the image is being loaded.
   * <p>
   * If the image is not immediately available in the memory cache this resource will be set
   * on the target {@code ImageView}.
   *
   * @param placeholderResId The placeholder drawable resource ID.
   * @since 1.0
   */
  NamoImageLoader placeholder(int placeholderResId);

  /**
   * An error drawable to show if the image is unable to load because of a dropped
   * connection.
   * <p>
   * If the image fails to load this resource will be set on the target
   *{@code ImageView}}.
   *
   * @param errorResId The error drawable resource ID.
   * @since 1.0
   */
  NamoImageLoader errorPlaceholder(int errorResId);

  /**
   * Asynchronously fulfills the image request into the specified {@code ImageView}.
   * <p>
   * This method keeps a weak reference to the {@code ImageView} in order to
   * automatically support object recycling.
   *
   * @param imageView The image view into which to load the image.
   * @since 1.0
   */
  void into(ImageView imageView);
}
