package com.namomedia.android;

import android.widget.TextView;

/**
 * Fluent API for loading text into a {@code TextView}.
 *
 * Namo ads provide different text lengths so that they are adaptable to different text view
 * sizes. This class will load the text of the appropriate size for the given text box.
 *
 * @since 2.0.0
 */
public interface NamoTextLoader {
  /**
   * Asynchronously fulfills the image request into the specified {@code ImageView}.
   * <p>
   * This method keeps a weak reference to the {@code TextView} in order to
   * automatically support object recycling.
   *
   * @param textView The image view into which to load the image.
   * @since 2.0.0
   */
  void into(TextView textView);

  /**
   * If there is no ad text available that fits in the {@code TextView}, this parameter determines
   * whether the loader is allowed to shrink the font size of the TextView.
   * <p>
   * The default value is <code>false</code>.
   *
   * @param allowChangeFontSize Whether to allow shrinking the font size.
   * @since 2.0.0
   */
  NamoTextLoader allowChangeFontSize(boolean allowChangeFontSize);
}
